@@ -526,7 +526,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
 #endif
 
   K4AboutData aboutData( "ksysguard", 0, ki18n( "System Monitor" ),
-                        WORKSPACE_VERSION_STRING, ki18n(Description), K4AboutData::License_GPL,
+                        PROJECT_VERSION, ki18n(Description), K4AboutData::License_GPL,
                         ki18n( "(c) 1996-2008 The KDE System Monitor Developers" ) );
   aboutData.addAuthor( ki18n("John Tapsell"), ki18n("Current Maintainer"), "john.tapsell@kde.org" );
   aboutData.addAuthor( ki18n("Chris Schlaeger"), ki18n("Previous Maintainer"), "cs@kde.org" );
@@ -541,7 +541,6 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
                        "Parts derived (by permission) from the sunos5\n"
                        "module of William LeFebvre's \"top\" utility." ),
                        "tk@Genetik.Uni-Bielefeld.DE" );
-  aboutData.setProgramIconName("utilities-system-monitor");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
 
@@ -550,6 +549,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
   KCmdLineArgs::addCmdLineOptions( options );
   // initialize KDE application
   KApplication *app = new KApplication;
+  app->setWindowIcon(QIcon::fromTheme("utilities-system-monitor"));
 
   KSGRD::SensorMgr = new KSGRD::SensorManager();
   KSGRD::Style = new KSGRD::StyleEngine();
